#ifndef CHROMEOS_CAMERA_LIB_DOCUMENT_SCANNING_DOCUMENT_SCANNER_IMPL_H_
#define CHROMEOS_CAMERA_LIB_DOCUMENT_SCANNING_DOCUMENT_SCANNER_IMPL_H_

#include <memory>
#include <vector>

#include "chromeos/camera/lib/document_scanning/document_scanner.h"

namespace cv {
class Mat;
}  // namespace cv

namespace photos_intel_actions {
class DocumentCornerDetector;
class DocumentQuadProcessor;
}  // namespace photos_intel_actions

namespace chromeos_camera {
namespace document_scanning {

class DocumentScannerImpl : public DocumentScanner {
 public:
  explicit DocumentScannerImpl(float score_threshold);
  ~DocumentScannerImpl() override;

  bool DetectCornersFromNV12Image(const uint8_t* nv12_image,
                                  std::vector<Point>* corners) override;

  bool DetectCornersFromJPEGImage(const uint8_t* jpeg_image,
                                  uint32_t image_size,
                                  std::vector<Point>* corners) override;
  bool DoPostProcessingFromJPEGImage(
      const uint8_t* jpeg_image, uint32_t image_size,
      const std::vector<Point>& corners, Rotation rotation,
      std::vector<uint8_t>* processed_jpeg_image) override;

 private:
  bool GetDocumentCornersFromMat(const cv::Mat& input_mat,
                                 std::vector<Point>* corners);

  std::unique_ptr<photos_intel_actions::DocumentCornerDetector> detector_;
  std::unique_ptr<photos_intel_actions::DocumentQuadProcessor> quad_processor_;
};

}  // namespace document_scanning
}  // namespace chromeos_camera

#endif  // CHROMEOS_CAMERA_LIB_DOCUMENT_SCANNING_DOCUMENT_SCANNER_IMPL_H_
